"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addHandler = void 0;
const tree_1 = require("../../generators/tree");
const project_graph_1 = require("../../project-graph/project-graph");
const output_1 = require("../../utils/output");
const params_1 = require("../../utils/params");
const sync_generators_1 = require("../../utils/sync-generators");
const workspace_root_1 = require("../../utils/workspace-root");
function addHandler(options) {
    if (options.verbose) {
        process.env.NX_VERBOSE_LOGGING = 'true';
    }
    const isVerbose = process.env.NX_VERBOSE_LOGGING === 'true';
    return (0, params_1.handleErrors)(isVerbose, async () => {
        const projectGraph = await (0, project_graph_1.createProjectGraphAsync)();
        const syncGenerators = await (0, sync_generators_1.collectAllRegisteredSyncGenerators)(projectGraph);
        const syncChanges = await (0, sync_generators_1.getSyncGeneratorChanges)(syncGenerators);
        if (!syncChanges.length) {
            return 0;
        }
        if (options.check) {
            output_1.output.error({
                title: `The workspace is out of sync`,
                bodyLines: [
                    `The following files must be updated:\n${syncChanges
                        .map((c) => c.path)
                        .join('\n')}`,
                ],
            });
            return 1;
        }
        (0, tree_1.flushChanges)(workspace_root_1.workspaceRoot, syncChanges);
        return 0;
    });
}
exports.addHandler = addHandler;
