"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.collectRegisteredGlobalSyncGenerators = exports.collectRegisteredTaskSyncGenerators = exports.runSyncGenerator = exports.collectAllRegisteredSyncGenerators = exports.getSyncGeneratorChanges = void 0;
const generate_1 = require("../command-line/generate/generate");
const generator_utils_1 = require("../command-line/generate/generator-utils");
const nx_json_1 = require("../config/nx-json");
const client_1 = require("../daemon/client/client");
const tree_1 = require("../generators/tree");
const project_graph_1 = require("../project-graph/project-graph");
const workspace_root_1 = require("./workspace-root");
async function getSyncGeneratorChanges(generators) {
    if (!client_1.daemonClient.enabled()) {
        return await runSyncGenerators(generators);
    }
    return await client_1.daemonClient.getSyncGeneratorChanges(generators);
}
exports.getSyncGeneratorChanges = getSyncGeneratorChanges;
async function collectAllRegisteredSyncGenerators(projectGraph) {
    if (!client_1.daemonClient.enabled()) {
        return [
            ...collectRegisteredTaskSyncGenerators(projectGraph),
            ...collectRegisteredGlobalSyncGenerators(),
        ];
    }
    return await client_1.daemonClient.getRegisteredSyncGenerators();
}
exports.collectAllRegisteredSyncGenerators = collectAllRegisteredSyncGenerators;
async function runSyncGenerator(tree, generatorSpecifier, projects) {
    const { collection, generator } = (0, generate_1.parseGeneratorString)(generatorSpecifier);
    const { implementationFactory } = (0, generator_utils_1.getGeneratorInformation)(collection, generator, workspace_root_1.workspaceRoot, projects);
    const implementation = implementationFactory();
    await implementation(tree, {});
    return tree.listChanges();
}
exports.runSyncGenerator = runSyncGenerator;
function collectRegisteredTaskSyncGenerators(projectGraph) {
    const taskSyncGenerators = new Set();
    for (const { data: { targets }, } of Object.values(projectGraph.nodes)) {
        if (!targets) {
            continue;
        }
        for (const target of Object.values(targets)) {
            if (!target.syncGenerators) {
                continue;
            }
            for (const generator of target.syncGenerators) {
                taskSyncGenerators.add(generator);
            }
        }
    }
    return taskSyncGenerators;
}
exports.collectRegisteredTaskSyncGenerators = collectRegisteredTaskSyncGenerators;
function collectRegisteredGlobalSyncGenerators(nxJson = (0, nx_json_1.readNxJson)()) {
    const globalSyncGenerators = new Set();
    if (!nxJson.sync?.globalGenerators?.length) {
        return globalSyncGenerators;
    }
    for (const generator of nxJson.sync.globalGenerators) {
        globalSyncGenerators.add(generator);
    }
    return globalSyncGenerators;
}
exports.collectRegisteredGlobalSyncGenerators = collectRegisteredGlobalSyncGenerators;
async function runSyncGenerators(generators) {
    const tree = new tree_1.FsTree(workspace_root_1.workspaceRoot, false, 'running sync generators');
    const projectGraph = await (0, project_graph_1.createProjectGraphAsync)();
    const { projects } = (0, project_graph_1.readProjectsConfigurationFromProjectGraph)(projectGraph);
    for (const generator of generators) {
        await runSyncGenerator(tree, generator, projects);
    }
    return tree.listChanges();
}
